@@ -670,6 +670,7 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
     SetImageDefaults(&resultPanorama);
 
     //transform structure holds input and output images, and some miscellaneous other information
+    memset(&transform, 0, sizeof(TrformStr));
     transform.src = &image1;    // Input image
     transform.dest = &resultPanorama;   // Output image
     transform.mode = 8;         // How to run transformation
@@ -782,8 +783,9 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
 
 
 
-        transform.interpolator = prefs->interpolator;
-        transform.gamma = prefs->gamma;
+        transform.interpolator  = prefs->interpolator;
+        transform.gamma         = prefs->gamma;
+        transform.fastStep      = prefs->fastStep;
         
         if (ptQuietFlag == 0) {
             sprintf(tmpStr, "Converting Image %d / %d", (loopCounter + 1),
@@ -824,8 +826,7 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
             if (prefs->pano.width == 0) {
                 // if the pano did not set the width, then try to set it
                 if (prefs->im.hfov != 0.0) {
-                    prefs->pano.width =
-                        prefs->im.width * prefs->pano.hfov / prefs->im.hfov;
+                    prefs->pano.width = (pt_int32)(prefs->im.width * prefs->pano.hfov / prefs->im.hfov);
                     prefs->pano.width /= 10;    // Round to multiple of 10
                     prefs->pano.width *= 10;
                 }
@@ -1015,9 +1016,10 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
 	    printf("Prefs pano: hvof %f, vfov %f pitch %f, roll %f\n", prefs->pano.hfov, prefs->pano.yaw, prefs->pano.pitch, prefs->pano.roll);
 	    printf("Prefs Interpolator %d:\n", prefs->interpolator);
 	    printf("Prefs Gamma %d:\n", prefs->gamma);
+        printf("Prefs FastT %d:/n,  prefs->fastStep);
 	    */
 
-            MakePano(&transform, prefs);
+            MyMakePano(&transform, prefs, loopCounter);
 
             if (transform.success == 0) {       // Error 
                 PrintError("Error converting image");
@@ -1682,7 +1684,6 @@ int panoCroppingMain(int argc,char *argv[], int operation, char *version, char *
     int ptForceProcessing = 0;
     int filesCount;
     int retVal;
-    FILE *testFile;
     pano_cropping_parms croppingParms;
     char outputPrefix[MAX_PATH_LENGTH];
     int ptDeleteSources = 0;
