@@ -50,7 +50,8 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 										// and source width/2 (4) and correctionradius (5)
 	double  lum_params[2];				// parameters to correct luminance variation	
 
-	struct  fDesc stack[10];			// Parameters for execute stack function
+    struct  fDesc stack[10];            // Parameters for execute stack function
+    struct  fDesc stackinv[10];         // Parameters for execute stack function
 
 	int		destwidth, destheight;
 	int 	xoff = 0, yoff = 0;
@@ -59,6 +60,7 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 	double  xdoff, ydoff;
 	Image	im, *dest, *src;
 	fDesc	fD;
+    fDesc	fDinv;
 
 	im.data = NULL; 
 
@@ -113,9 +115,9 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 		// MRDL 2003/08/25 Makes behavior consistent with lens distortion correction
 		// algorithm
         if( TrPtr->src->width < TrPtr->src->height )
-            sizesqr = (TrPtr->src->width/2.0) * (TrPtr->src->width/2.0);
+            sizesqr = (int)((TrPtr->src->width/2.0) * (TrPtr->src->width/2.0));
         else
-            sizesqr = (TrPtr->src->height/2.0) * (TrPtr->src->height/2.0);
+            sizesqr = (int)((TrPtr->src->height/2.0) * (TrPtr->src->height/2.0));
 
 		if( prefs->lum_params[0] ==  prefs->lum_params[1] &&
 			prefs->lum_params[1] ==  prefs->lum_params[2] )  // Color independent
@@ -161,12 +163,12 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 			if( prefs->width  )
 				destwidth 		= prefs->width;
 			else
-				destwidth 		= (double)TrPtr->src->width * (double)prefs->height / (double)TrPtr->src->height;
+				destwidth 		= (int)((double)TrPtr->src->width * (double)prefs->height / (double)TrPtr->src->height);
 			
 			if( prefs->height)
 				destheight 		= prefs->height;
 			else
-				destheight		= (double)TrPtr->src->height * (double)prefs->width / (double)TrPtr->src->width;
+				destheight		= (int)((double)TrPtr->src->height * (double)prefs->width / (double)TrPtr->src->width);
 		}
 		else
 		{
@@ -264,12 +266,12 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 			if( prefs->width  )
 				destwidth 		= prefs->width;
 			else
-				destwidth 		= (double)TrPtr->src->width * (double)prefs->height / (double)TrPtr->src->height;
+				destwidth 		= (int)((double)TrPtr->src->width * (double)prefs->height / (double)TrPtr->src->height);
 			
 			if( prefs->height)
 				destheight 		= prefs->height;
 			else
-				destheight		= (double)TrPtr->src->height * (double)prefs->width / (double)TrPtr->src->width;
+				destheight		= (int)((double)TrPtr->src->height * (double)prefs->width / (double)TrPtr->src->width);
 		}
 		
 		if( destwidth <= 0 || destheight <= 0 )
@@ -491,24 +493,7 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 				SetDesc(stack[i],resize,scale_params); i++;
 			}
 
-			if( prefs->shear )
-			{
-				shear_params[0] = prefs->shear_x / TrPtr->src->height;
-				shear_params[1] = prefs->shear_y / TrPtr->src->width;
-				SetDesc(stack[i],shear,shear_params); i++;
-			}
-
-			if (prefs->horizontal)
-			{
-				SetDesc(stack[i],horiz,&(prefs->horizontal_params[color]) ); i++;
-			}
-
-			if (prefs->vertical)
-			{
-				SetDesc(stack[i],vert,&(prefs->vertical_params[color])); i++;
-			}
-
-
+            // JMW 2008/01/03 make the order the same as Adjust doing correct
 			if( prefs->radial )
 			{
 				switch( prefs->correction_mode)
@@ -528,7 +513,25 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 					radial_params[j] = prefs->radial_params[color][j];
 				radial_params[5] = prefs->radial_params[color][4];
 			}
-			if( prefs->cutFrame )
+
+			if (prefs->vertical)
+			{
+				SetDesc(stack[i],vert,&(prefs->vertical_params[color])); i++;
+			}
+
+			if (prefs->horizontal)
+			{
+				SetDesc(stack[i],horiz,&(prefs->horizontal_params[color]) ); i++;
+			}
+
+			if( prefs->shear )
+			{
+				shear_params[0] = prefs->shear_x / TrPtr->src->height;
+				shear_params[1] = prefs->shear_y / TrPtr->src->width;
+				SetDesc(stack[i],shear,shear_params); i++;
+			}
+            
+            if( prefs->cutFrame )
 			{
 				if( xoff != 0 )
 				{
@@ -541,9 +544,8 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 					ydoff = (double)yoff + 0.5 * ( prefs->fheight - TrPtr->src->height) ;
 					SetDesc(stack[i],vert,&ydoff); i++;
 				}
-				
-
 			}
+
 			stack[i].func = (trfn)NULL;
 
 			if( 	!prefs->resize 		&&
@@ -557,12 +559,21 @@ void 	correct	(TrformStr *TrPtr, cPrefs *prefs)
 			}
 			else if( TrPtr->success != 0 && i != 0 )
 			{
-				fD.func = execute_stack_new; fD.param = stack;
-				transForm( TrPtr,  &fD, k);
+                // Copy and reverse the stack to make the inverse stack
+                int ii = 0;
+                while(i)
+                {
+                  stackinv[ii] = stack[i-1];
+                  i--;
+                  ii++;
+                }
+                stackinv[ii].func = (trfn)NULL;
+
+				fD.func    = execute_stack_new; fD.param    = stack;
+                fDinv.func = execute_stack_new; fDinv.param = stackinv;
+                transFormEx( TrPtr, &fD, &fDinv, k, 1 );
 			}
             
-            
-            
             switch(k) // We use k as control var for a little statemachine:
             {
                 case 0:// RGB
@@ -654,6 +665,8 @@ int 	cutTheFrame	( Image *dest, Image *src, int width, int height, int showprogr
 			PrintError("Could not allocate %ld bytes", dest->dataSize );
 			return -1;
 		}
+
+    memset(&TrCrop, 0, sizeof(TrformStr));
 		TrCrop.src 	= src;
 		TrCrop.dest = dest;
 		TrCrop.success = 0;
