@@ -48,7 +48,7 @@
 // Dynamically allocate scanline buffer in writeWhiteBackground,
 // to avoid buffer overflow and crash on large images.
 // Fix 16bit Radial Shift and Adjust - Kevin & Jim 2004 July
-
+// 2006 Max Lyons         - Various modifications
 #include <assert.h>
 #include "filter.h"
 
@@ -149,6 +149,7 @@ int panoPSDResourceWrite(file_spec fnum, pt_uint16 resource, pt_uint16 len, pt_u
   rtn += count;
   WRITEINT32(len); //size of the record (4 bytes)
   rtn += count;
+   
 
   if (dataLen > 0 && resourceData != NULL) {
     mywrite( fnum, dataLen, resourceData );
@@ -285,6 +286,7 @@ int panoPSDResourcesBlockWrite(Image *im, file_spec   fnum)
   return rtn;
 
 
+  
 }
 
 
@@ -1980,7 +1982,7 @@ char* LoadScript( fullPath* scriptFile )
 
     if( myopen( scriptFile, read_text, fnum ))
     {
-        PrintError("Error Opening Scriptfile");
+        PrintError("Error Opening Scriptfile: %s", scriptFile->name);
         goto _loadError;
     }
     
@@ -2002,7 +2004,7 @@ char* LoadScript( fullPath* scriptFile )
     }
     if( myopen( scriptFile, read_text, fnum ))
     {
-        PrintError("Error Opening Scriptfile");
+        PrintError("Error Opening Scriptfile: %s", scriptFile->name);
         goto _loadError;
     }
     
@@ -2408,7 +2410,7 @@ int panoFileMakeTemp(fullPath * path)
 // Read an image
 int panoImageRead(Image * im, fullPath * sfile)
 {
-    char *ext, extension[4];
+    char *ext, extension[5];
     int i;
 
     assert(sfile != NULL);
@@ -2416,14 +2418,14 @@ int panoImageRead(Image * im, fullPath * sfile)
     
     printf("Filename %s\n", sfile->name);
     ext = strrchr(sfile->name, '.');
-    if (ext == NULL || strlen(ext) != 4) {
+    if (ext == NULL || strlen(ext) < 4 || strlen(ext) > 5) {
 	PrintError("Unsupported file format [%s]: must have extension JPG, PNG, TIF, BMP or HDR", sfile);
 	return 0;
     }
     ext++;
     strcpy(extension, ext);
     // convert to lowercase
-    for (i = 0; i < 3; i++)
+    for (i = 0; i < 4; i++)
         extension[i] = tolower(extension[i]);
     
     if (strcmp(extension, "ppm") == 0) {
@@ -2432,11 +2434,11 @@ int panoImageRead(Image * im, fullPath * sfile)
     else if (strcmp(extension, "jpg") == 0) {
         return panoJPEGRead(im, sfile);
     } 
-    else if (strcmp(extension, "tif") == 0) {
+    else if (strcmp(extension, "tif") == 0 || strcmp(extension, "tiff") == 0) {
         return panoTiffRead(im, sfile->name);
     } 
     else if (strcmp( extension, "bmp" ) == 0 ) {
-#ifdef __Win__		
+#ifdef WIN32		
 		return panoBMPRead(  im, sfile );
 #else
 		PrintError("BMP is not a supported format in this operating system");
@@ -2514,7 +2516,6 @@ char *panoFileExists(fullPath *ptrFiles, int filesCount)
 // Check if a file exists. Returns 1 if it does exist, 0 otherwise
 int panoSingleFileExists(char * filename)
 {
-    int i;
     FILE *testFile;
 	if ((testFile = fopen(filename, "r"))!= NULL) {
         fclose(testFile);
