@@ -29,6 +29,9 @@
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
+#ifndef _MSC_VER
+#include <unistd.h>
+#endif
 #include <math.h>
 #include <tiff.h>
 #include <assert.h>
@@ -120,7 +123,8 @@ void dispatch (TrformStr *TrPtr, sPrefs *spref)
                                         else
                                         {
                                                 TrPtr->interpolator = spref->interpolator;
-                                                TrPtr->gamma            = spref->gamma;
+                                                TrPtr->gamma        = spref->gamma;
+                                                TrPtr->fastStep     = spref->fastStep;
                                                         
                                                 writePrefs( (char*)prPtr, TrPtr->tool );
                                                 writePrefs( (char*)spref, _sizep );
@@ -187,6 +191,7 @@ void DoTransForm( TrformStr *TrPtr, panoPrefs *prPtr )
 //              case _interpolate:              
 //                      interp      (TrPtr, &prPtr->iP);
 //                      break;
+#if 0
                 case _panright:
                 case _panleft:
                 case _panup:
@@ -198,6 +203,7 @@ void DoTransForm( TrformStr *TrPtr, panoPrefs *prPtr )
                 case _increment:
                         pan(TrPtr,  &prPtr->pc);
                         break;
+#endif
         }
         Progress( _disposeProgress, "" ); 
         return;
@@ -305,8 +311,8 @@ void filter( TrformStr *TrPtr, flfn func, flfn16 func16, void* params, int color
 
         // Variables used to convert screen coordinates to cartesian coordinates
         
-        int                             w2 = TrPtr->dest->width / 2.0 - 0.5;  // Steve's L
-        int                             h2 = TrPtr->dest->height / 2.0 - 0.5;  
+        int                             w2 = (int)(TrPtr->dest->width / 2.0 - 0.5);  // Steve's L
+        int                             h2 = (int)(TrPtr->dest->height / 2.0 - 0.5);  
 
         // Selection rectangle
         PTRect                  destRect;
@@ -858,6 +864,12 @@ void SetImageDefaults(Image *im){
         im->selection.bottom    = 0;
         im->selection.left      = 0;
         im->selection.right     = 0;
+        im->cropInformation.cropped_height  = 0;
+        im->cropInformation.cropped_width   = 0;
+        im->cropInformation.full_height     = 0;
+        im->cropInformation.full_width      = 0;
+        im->cropInformation.x_offset        = 0;
+        im->cropInformation.y_offset        = 0;
         panoSetMetadataDefaults(&im->metadata);
 }
 
@@ -935,21 +947,17 @@ int HaveEqualSize( Image *im1, Image *im2 )
 
 void SetSizeDefaults( sPrefs *pref)
 {
-        
-        pref->magic                     = 70;                   // File validity check; must be 70
-        pref->displayPart       = TRUE;                 // Display cropped/framed image ?
-        pref->saveFile          = FALSE;                // Save to tempfile?
-        pref->launchApp         = FALSE;                // Open sFile ?
-        pref->interpolator      = _poly3;
-        makePathForResult( &(pref->sFile) );
-        makePathToHost ( &(pref->lApp) );
-        pref->gamma                     = 1.0;
-        pref->noAlpha           = FALSE;                        // Check only for Photoshop LE
-        pref->optCreatePano = TRUE;
-
-        // FS+
-        fastTransformStep = 0;  // the value will be changed in parser.c
-        // FS-
+    pref->magic             = 70;                   // File validity check; must be 70
+    pref->displayPart       = TRUE;                 // Display cropped/framed image ?
+    pref->saveFile          = FALSE;                // Save to tempfile?
+    pref->launchApp         = FALSE;                // Open sFile ?
+    pref->interpolator      = _spline36;            //
+    makePathForResult( &(pref->sFile) );
+    makePathToHost ( &(pref->lApp) );
+    pref->gamma             = 1.0;
+    pref->noAlpha           = FALSE;                // Check only for Photoshop LE
+    pref->optCreatePano     = TRUE;
+    pref->fastStep          = FAST_TRANSFORM_STEP_NONE; // the value will be changed in parser.c
 }
 
 
@@ -1280,22 +1288,22 @@ void panoDumpMetadata(pano_ImageMetadata * metadata, char *message)
 }
 
 /* ENDIAN aware file i/o funtions.  Used for reading and writing photoshop files */
-Boolean panoWriteUCHAR(file_spec fnum, UCHAR theChar )
+Boolean panoWriteUCHAR(nfile_spec fnum, UCHAR theChar )
 { 
-    return write( fnum, 1, &theChar ) == 1;
+    return write( fnum, &theChar, 1 ) == 1;
 }
 
-Boolean panoWriteSHORT(file_spec fnum, USHORT theShort )
+Boolean panoWriteSHORT(nfile_spec fnum, USHORT theShort )
 {
     char data[2], *d;
     d = data;
     
     assert(sizeof(USHORT) == 2);
     SHORTNUMBER( theShort, d );
-    return write( fnum, 2, data ) == 2;
+    return write( fnum, data, 2 ) == 2;
 }
 
-Boolean panoWriteINT32(file_spec fnum, ULONG theLong )
+Boolean panoWriteINT32(nfile_spec fnum, ULONG theLong )
 {
     size_t count = 4;
     char data[4], *d;
@@ -1305,19 +1313,19 @@ Boolean panoWriteINT32(file_spec fnum, ULONG theLong )
     
     LONGNUMBER( theLong, d );
     
-    return write( fnum, 4, data ) == 4;
+    return write( fnum, data, 4 ) == 4;
 }
 
-Boolean panoReadUCHAR(file_spec fnum, UCHAR *pChar )
+Boolean panoReadUCHAR(nfile_spec fnum, UCHAR *pChar )
 {
-    return read( fnum, 1, pChar )== 1;
+    return read( fnum, pChar, 1 )== 1;
 }
 
-Boolean panoReadSHORT(file_spec fnum, USHORT *pShort )
+Boolean panoReadSHORT(nfile_spec fnum, USHORT *pShort )
 {
     char data[2];
     char *d;
-    if (read( fnum, 2, data ) != 2) {
+    if (read( fnum, data, 2 ) != 2) {
         return FALSE;
     }
 
@@ -1328,10 +1336,10 @@ Boolean panoReadSHORT(file_spec fnum, USHORT *pShort )
     return TRUE;
 }
 
-Boolean panoReadINT32(file_spec fnum, ULONG *pLong )
+Boolean panoReadINT32(nfile_spec fnum, ULONG *pLong )
 {
     char data[4], *d;
-    if (read( fnum, 4, data )!= 4) {
+    if (read( fnum, data, 4 )!= 4) {
         return FALSE;
     }
     d = data;
