@@ -30,7 +30,7 @@
 #include <limits.h>
 
 #include "panorama.h"
-#include "tiffio.h"
+//#include "tiffio.h"
 
 #ifndef TRUE
 	#define TRUE 1
@@ -97,16 +97,14 @@ enum{
 								else c=(float)(x);
 
 
-#define MAX_FISHEYE_FOV		160.0
+#define MAX_FISHEYE_FOV		179.0
 
 extern int JavaUI; // Flag to indicate use of java dialogs
 void JPrintError( char* text );
 
-
-extern int fastTransformStep;		// defined in resample.c
 #define FAST_TRANSFORM_STEP_NORMAL	40
 #define FAST_TRANSFORM_STEP_MORPH	6
-// FS-
+#define FAST_TRANSFORM_STEP_NONE    0
 
 struct PTPoint
 {
@@ -234,20 +232,21 @@ enum{										// Enumerates for aPrefs.mode
 		_useScript = 8,						// else use options
 	};
 
-struct adjust_Prefs{		//  Preferences structure for tool adjust
-		pt_int32	magic;	//  File validity check, must be 50
-		pt_int32	mode;	//  What to do: create Panorama etc?
-		Image	im;	//  Image to be inserted/extracted
-		Image	pano;	//  Panorama to be created/ used for extraction
-		
-		stBuf	sBuf;
-		fullPath scriptFile;	// On Mac: Cast to FSSpec; else: full path to scriptFile
-		int     nt;	// morphing triangles
-		PTTriangle 	*ts; // Source triangles
-		PTTriangle 	*td; // Destination triangles
+struct adjust_Prefs{                  //  Preferences structure for tool adjust
+    pt_int32            magic;        //  File validity check, must be 50
+    pt_int32            mode;         //  What to do: create Panorama etc?
+    Image               im;           //  Image to be inserted/extracted
+    Image               pano;         //  Panorama to be created/ used for extraction
 
-		int interpolator;
-		double gamma;		
+    stBuf               sBuf;
+    fullPath            scriptFile;   // On Mac: Cast to FSSpec; else: full path to scriptFile
+    int                 nt;           // morphing triangles
+    PTTriangle         *ts;           // Source triangles
+    PTTriangle         *td;           // Destination triangles
+
+    int                 interpolator; // Which interpolator to use 
+    double              gamma;        // Gamma correction value
+    int                 fastStep;     // 0 no fast Transformation (default), FAST_TRANSFORM_STEP_MORPH, FAST_TRANSFORM_STEP_NORMAL
 };
 		
 		
@@ -266,22 +265,23 @@ union panoPrefs{
 typedef union panoPrefs panoPrefs;
 
 
-struct size_Prefs{								// Preferences structure for 'pref' dialog
-		pt_int32			magic;					//  File validity check; must be 70
-		int				displayPart;			// Display cropped/framed image ?
-		int				saveFile;				// Save to tempfile? 0-no, 1-yes
-		fullPath		sFile;					// Full path to file (short name)
-		int				launchApp;				// Open sFile ?
-		fullPath		lApp;					// the Application to launch
-		int				interpolator;			// Which interpolator to use 
-		double			gamma;					// Gamma correction value
-		int				noAlpha;				// If new file is created: Don't save mask (Photoshop LE)
-		int				optCreatePano;			// Optimizer creates panos? 0  no/ 1 yes
-		} ;
+struct size_Prefs{                      // Preferences structure for 'pref' dialog
+    pt_int32        magic;              //  File validity check; must be 70
+    int             displayPart;        // Display cropped/framed image ?
+    int             saveFile;           // Save to tempfile? 0-no, 1-yes
+    fullPath        sFile;              // Full path to file (short name)
+    int             launchApp;          // Open sFile ?
+    fullPath        lApp;               // the Application to launch
+    int             interpolator;       // Which interpolator to use 
+    double          gamma;              // Gamma correction value
+    int             noAlpha;            // If new file is created: Don't save mask (Photoshop LE)
+    int             optCreatePano;      // Optimizer creates panos? 0  no/ 1 yes
+    int             fastStep;           // 0 no fast Transformation (default), FAST_TRANSFORM_STEP_MORPH, FAST_TRANSFORM_STEP_NORMAL
+} ;
 
 typedef struct size_Prefs sPrefs;
-		
-		
+
+
 
 #if 0
 struct controlPoint{							// Control Points to adjust images
@@ -558,7 +558,7 @@ void PT_setInfoDlgFcn(int (*ptr)(int, char *));            // set custom info ca
 int 	infoDlg ( int command, char* argument );	// Display info: same argumenmts as progress
 void PT_setErrorFcn( void (*ptr)( char* , va_list va));         // set custom error function
 void  	PrintError( char* fmt, ...);				// Error Reporting
-void dieWithError(char*fmt, ...);
+void dieWithError(const char*fmt, ...);
 
 int 	ccommand( char ***argvPtr);					// Shell for standalone programs
 
@@ -811,6 +811,7 @@ int shear				( double x_dest,double  y_dest, double* x_src, double* y_src, void*
 int horiz				( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
 int vert				( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
 int radial				( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
+int radial_brown			( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
 
 
 int persp_sphere		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
@@ -848,17 +849,37 @@ int erect_albersequalareaconic	( double x_dest,double  y_dest, double* x_src, do
 int albersequalareaconic_distance	( double *x_src, void* params );
 int millercylindrical_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
 int erect_millercylindrical		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int panini_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int erect_panini		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int equipanini_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int erect_equipanini		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
 
+int arch_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int erect_arch		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+
+int biplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int erect_biplane		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int biplane_distance ( double width, double b, void* params );
+int triplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int erect_triplane		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+int triplane_distance ( double width, double b, void* params );
 
 int mirror_sphere_cp	( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
 int mirror_pano		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
 int sphere_cp_mirror	( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );	
-int sphere_tp_pano		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
 
+int sphere_tp_pano		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
 int pano_sphere_tp		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params );
+//int sphere_tp_mirror( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+//int mirror_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+int sphere_tp_equisolid( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+int equisolid_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+int sphere_tp_orthographic( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+int orthographic_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
 
 int rotate_erect		( double x_dest, double y_dest, double* x_src, double* y_src, void* params );
 int inv_radial			( double x_dest, double y_dest, double* x_src, double* y_src, void* params );
+int inv_radial_brown		( double x_dest, double y_dest, double* x_src, double* y_src, void* params );
 
 int vertical			( double x_dest, double y_dest, double* x_src, double* y_src, void* params );
 int inv_vertical		( double x_dest, double y_dest, double* x_src, double* y_src, void* params );
@@ -947,6 +968,7 @@ extern sPrefs			*gsPrPtr;
 	#include "sys_mac.h"
 	
 	#define			file_spec							short
+	#define			nfile_spec							short
 	#define			myopen( path, perm, fspec )			( FSpOpenDF( path, perm, &fspec ) != noErr )
 	#define			mywrite( fspec, count, data )		FSWrite	(fspec, &count, data) 
 	#define 		myread(  fspec, count, data )		FSRead  (fspec, &count, data) 
@@ -962,6 +984,7 @@ extern sPrefs			*gsPrPtr;
 			
 #else // __Mac__, use ANSI-filefunctions
 	#define		file_spec			FILE*
+	#define		nfile_spec			int
 	#define		myopen( path, perm, fspec )	( (fspec = fopen( (path)->name, perm )) == NULL)
 	#define		mywrite( fspec, count, data )	count = fwrite( data, 1, count, fspec)
 	#define 	myread( fspec, count, data )	count = fread( data, 1, count, fspec ) 
@@ -988,12 +1011,12 @@ extern sPrefs			*gsPrPtr;
 #endif
 
 /* ENDIAN aware file i/o funtions.  Used for reading and writing photoshop files */
-Boolean panoWriteUCHAR(file_spec fnum, UCHAR   theChar );
-Boolean panoWriteSHORT(file_spec fnum, USHORT  theShort );
-Boolean panoWriteINT32(file_spec fnum, ULONG   theLong );
-Boolean panoReadUCHAR (file_spec fnum, UCHAR  *pChar );
-Boolean panoReadSHORT (file_spec fnum, USHORT *pShort );
-Boolean panoReadINT32 (file_spec fnum, ULONG  *pLong );
+Boolean panoWriteUCHAR(nfile_spec fnum, UCHAR   theChar );
+Boolean panoWriteSHORT(nfile_spec fnum, USHORT  theShort );
+Boolean panoWriteINT32(nfile_spec fnum, ULONG   theLong );
+Boolean panoReadUCHAR (nfile_spec fnum, UCHAR  *pChar );
+Boolean panoReadSHORT (nfile_spec fnum, USHORT *pShort );
+Boolean panoReadINT32 (nfile_spec fnum, ULONG  *pLong );
     
 
 #define PANO_DEFAULT_PIXELS_PER_RESOLUTION  150.0
@@ -1033,3 +1056,4 @@ void panoDumpMetadata(pano_ImageMetadata * metadata, char *message);
 // number of different temporary files
 #define MAX_TEMP_TRY    1000000
 
+
