@@ -575,7 +575,19 @@ int rect_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void
 	*x_src = distanceparam * tan(phi);
 	*y_src = distanceparam / (tan( theta ) * cos(phi));
 #endif
-    return 1;
+        // normalize phi to be in the -PI, PI range
+        while(phi <= -PI)
+            phi += 2*PI;
+        while(phi > PI)
+            phi -= 2*PI;
+
+        // check if the point is "in front" of the camera
+        if (phi < -PI/2.0 || phi > PI/2.0) {
+            // behind, transform considered invalid
+            return 0;
+        } else
+            return 1;
+
 }
 // This is the cylindrical projection
 int pano_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
@@ -658,7 +670,6 @@ int erect_lambertazimuthal( double x_dest,double  y_dest, double* x_src, double*
     *x_src = distanceparam * atan2( x * sin(c), (ro * cos(c)));
 
     return 1;
-
 }
 
 
@@ -695,6 +706,39 @@ int millercylindrical_erect( double x_dest,double  y_dest, double* x_src, double
     return 1;
 }
 
+/** convert from erect to miller */
+int arch_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    // params: distanceparam
+    double phi;
+
+    phi = y_dest/distanceparam;
+    if (phi < 0) {
+        millercylindrical_erect(x_dest, y_dest, x_src, y_src, params);
+    } else {
+        lambert_erect(x_dest, y_dest, x_src, y_src, params);
+    }
+
+    return 1;
+}
+
+/** convert from erect to miller */
+int erect_arch( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    // params: distanceparam
+    double y;
+
+    y = y_dest/distanceparam;
+    if (y < 0) {
+        erect_millercylindrical(x_dest, y_dest, x_src, y_src, params);
+    } else {
+        erect_lambert(x_dest, y_dest, x_src, y_src, params);
+    }
+
+    return 1;
+}
+
+
 
 /** convert from mercator to erect */
 int erect_millercylindrical( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
@@ -710,6 +754,116 @@ int erect_millercylindrical( double x_dest,double  y_dest, double* x_src, double
 }
 
 
+/** convert from erect to panini */
+int panini_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    // params: distanceparam
+  // this is the inverse
+
+    double phi, lambdaHalf, temp,y,x;
+
+    phi = y_dest/distanceparam;
+    lambdaHalf = x_dest/ (distanceparam*2);
+    x = 2 * tan (lambdaHalf);
+
+    // Conver from central cylindrical
+    phi = tan(phi);
+
+    *x_src = distanceparam * x;
+    temp  = cos(lambdaHalf);
+    
+    y = tan(phi) / (temp * temp);
+    
+    // At this point we have mapped to central cylindrical, now to equirectangular
+      
+    *y_src = distanceparam *  y;
+
+    return 1;
+}
+
+
+/** convert from panini to erect */
+int erect_panini( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    double y;
+    double x;
+    double temp;
+
+    double  lambda;
+
+    double phi;
+    y = y_dest/distanceparam;
+    x = x_dest/distanceparam;
+    lambda = atan(x/2);
+ 
+    // then project from opposite edge of the cylinder
+    temp = cos(lambda);
+    phi = y * temp * temp;
+
+    // First convert to central cylindrical
+    phi  = atan( phi);
+
+    *x_src = 2 * lambda * distanceparam;
+    *y_src = atan(phi) * distanceparam;
+
+    return 1;
+}
+
+
+
+/** convert from erect to equi panini */
+int equipanini_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    // params: distanceparam
+  // this is the inverse
+
+    double phi, lambdaHalf, temp,y,x;
+
+    phi = y_dest/distanceparam;
+    lambdaHalf = x_dest/ (distanceparam*2);
+    x = 2 * tan (lambdaHalf);
+
+    *x_src = distanceparam * x;
+    temp  = cos(lambdaHalf);
+    
+    y = tan(phi) / (temp * temp);
+    
+    // At this point we have mapped to central cylindrical, now to equirectangular
+      
+    *y_src = distanceparam *  y;
+
+    return 1;
+}
+
+
+/** convert from equi panini to erect */
+int erect_equipanini( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+    double y;
+    double x;
+    double temp;
+
+    double  lambda;
+
+    double phi;
+    y = y_dest/distanceparam;
+    x = x_dest/distanceparam;
+    lambda = atan(x/2);
+ 
+    // then project from opposite edge of the cylinder
+    temp = cos(lambda);
+    phi = y * temp * temp;
+
+    *x_src = 2 * lambda * distanceparam;
+    *y_src = atan(phi) * distanceparam;
+
+    return 1;
+}
+
+
+
+
+
 /** convert from erect to lambert */
 int lambert_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
@@ -880,9 +1034,29 @@ int erect_stereographic_old( double x_dest,double  y_dest, double* x_src, double
 
 int albersEqualAreaConic_ParamCheck(Image *im) 
 {
-
     //Parameters: phi1, phi2, phi0, n, C, rho0, yoffset
-    double phi1, phi2, n, C, rho0, phi0, y1, y2, y, twiceN;
+    // Albers Equal-Area Conic Projection
+    // parameters phi0, phi1, phi2:
+    //   latitude values
+    // parameter n:
+    //   (latex) $\frac{1}{2}\left(\sin\phi_1 + \sin\phi_2\right)$
+    //   (C) (sin(phi1) + sin(phi2)) / 2.0
+    // parameter C:
+    //   (latex) $\cos^2\phi_1 + 2 n \sin\phi_1$
+    //   (C) cos(phi1) * cos(phi1) + 2.0 * n * sin(phi1)
+    // parameter rho0:
+    //   (latex) $\frac{\sqrt{C - 2 n \sin\phi_0}}{n}$
+    //   (C) sqrt(C - 2.0 * n * sin(phi0))
+    // yoffset:
+    //   offset in y-direction for centering
+
+    double phi0, phi1, phi2, n, C, rho0, yoffset;
+    double Aux_2N; /* auxiliary variable for (2 * n) */
+    double Aux_sin_phi0; /* auxiliary variable for sin(phi0) */
+    double Aux_sin_phi1; /* auxiliary variable for sin(phi1) */
+    double Aux_sin_phi2; /* auxiliary variable for sin(phi2) */
+    double Aux_yl, Aux_yo; /* auxiliary variables for lower and upper y value */
+    double Aux_1; /* auxiliary variable */
     double phi[] = {-PI/2, 0, PI/2};
     double lambda[] = {-PI, 0, PI};
     int i, j, first;
@@ -890,12 +1064,13 @@ int albersEqualAreaConic_ParamCheck(Image *im)
     assert(PANO_PROJECTION_MAX_PARMS >= 2);
 
     if (im->formatParamCount == 1) {
-	// WHen only one parameter provided, assume phi1=phi0
+        // When only one parameter provided, assume phi1 = phi0
 	im->formatParamCount = 2;
 	im->formatParam[1] = im->formatParam[0];
     }
 
     if (im->formatParamCount == 0) {
+        // if no latitude values given, then set defaults
 	im->formatParamCount = 2;
 	im->formatParam[0] = 0;  //phi1
 	im->formatParam[1] = -60; //phi2
@@ -914,43 +1089,60 @@ int albersEqualAreaConic_ParamCheck(Image *im)
 	im->precomputedValue[0] =  -1.0 * im->formatParam[0];
 	im->precomputedValue[1] =  -1.0 * im->formatParam[1];
 
+        phi0 = 0; // default value of phi0
 	phi1 = im->precomputedValue[0] * PI / 180.0; //phi1 to rad
 	phi2 = im->precomputedValue[1] * PI / 180.0; //phi2 to rad
 
-	//Calculate the y at 6 different positions (lambda=-pi,0,+pi; phi=-pi/2,0,pi/2).
+        // precompute sinus functions
+        Aux_sin_phi0 = sin(phi0);
+        Aux_sin_phi1 = sin(phi1);
+        Aux_sin_phi2 = sin(phi2);
+        // precompute auxiliary term (2 * n)
+        Aux_2N = Aux_sin_phi1 + Aux_sin_phi2;
+
+        // calculate parameters
+        // The stability of these operations should be improved
+        n = Aux_2N / 2.0;
+        C = 1.0 + Aux_sin_phi1 * Aux_sin_phi2;
+        Aux_1 = (C - (Aux_2N * Aux_sin_phi0));
+        Aux_1 = ( (Aux_1 > 0.0) ? (sqrt(Aux_1)) : (0.0) );
+        rho0 = ( (n != 0.0) ? (Aux_1 / n) : (1.7E+308) );
+
+        // calculate the y at 6 different positions (lambda=-pi,0,+pi; phi=-pi/2,0,pi/2).
 	///Then calculate a yoffset so that the image is centered.
 	first = 1;
-	for (i = 0; i < 3; i++) for (j = 0; j < 3; j++) {
-	    y = sqrt(pow(cos(phi1), 0.2e1) + 0.2e1 * (sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) * sin(phi1)) / (sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) - sqrt(pow(cos(phi1), 0.2e1) + 0.2e1 * (sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) * sin(phi1) - 0.2e1 * (sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) * sin(phi[i])) / (sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) * cos((sin(phi1) / 0.2e1 + sin(phi2) / 0.2e1) * lambda[j]);
-	    if (!isnan(y)) {
-		if (first || y < y1) y1 = y;
-		if (first || y > y2) y2 = y;
+        for (i = 0; i < 3; i++) {
+            for (j = 0; j < 3; j++) {
+                Aux_1 = C - (sin(phi[i]) * Aux_2N);
+                if (C >= 0.0 && Aux_1 >= 0.0 && n != 0.0) {
+                    Aux_1 = (sqrt(C) - (sqrt(Aux_1) * cos(n * lambda[j]))) / n;
+                    if (first || Aux_1 < Aux_yl) {
+                        Aux_yl = Aux_1;
+                    }
+                    if (first || Aux_1 > Aux_yo) {
+                        Aux_yo = Aux_1;
+                    }
 		first = 0;
 	    }
 	}
+        }
 	if (first) {
-	    y = 0;
-	} else {
-	    y = y1 + fabs(y1 - y2)/2.0;
+            yoffset = 0.0;
+        }
+        else {
+            yoffset = Aux_yl + fabs(Aux_yl - Aux_yo) / 2.0;
 	}
 
-	// The stability of these operations should be improved
-	phi0 = 0;
-	twiceN = sin(phi1) + sin(phi2);
-	n = twiceN /2.0;
-	C = cos(phi1) * cos(phi1) + 2.0 * n * sin(phi1);
-	rho0 = sqrt(C - 2.0 * n * sin(phi0)) / n;
-
 	im->precomputedValue[0] = phi1;
 	im->precomputedValue[1] = phi2;
 	im->precomputedValue[2] = phi0;
 	im->precomputedValue[3] = n;
 	im->precomputedValue[4] = C;
 	im->precomputedValue[5] = rho0;
-	im->precomputedValue[6] = y;
+        im->precomputedValue[6] = yoffset;
 	im->precomputedValue[7] = n*n;
-	im->precomputedValue[8] = sin(phi1) + sin(phi2);
-	im->precomputedValue[9] = twiceN;
+        im->precomputedValue[8] = Aux_2N;
+        im->precomputedValue[9] = Aux_2N;
 
 	//	printf("Parms phi1 %f phi2 %f pho0 %f, n %f, C %f, rho0 %f, %f\n", 
 	//	       phi1, phi2, phi0, n, C, rho0, y);
@@ -961,7 +1153,9 @@ int albersEqualAreaConic_ParamCheck(Image *im)
 	assert(!isnan(im->precomputedValue[i]));
     }
     
-    if (im->precomputedCount > 0) return 1;
+    if (im->precomputedCount > 0) {
+        return 1;
+    }
     //    PrintError("false in alberts equal area parameters");
     return 0;
 }
@@ -1104,13 +1298,14 @@ int albersequalareaconic_distance(double* x_src, void* params) {
     phi2 = mp->pn->precomputedValue[1];
 
     //lambda where x is a maximum.
-    if (phi1 == phi2  &&
-	phi1 == 0.0) {
+    if ( (phi1 == phi2 && phi1 == 0.0) 
+        || (phi1 == -phi2) )
+    {
 	// THIS IS A HACK...it needs to further studied
 	// why this when phi1==phi2==0 
 	// this functions return 0
 	// Avoid approximation error
-	PrintError("The Albers projection cannot be used for phi1==phi2==0. Use Lambert Cylindrical Equal Area instead");
+	// PrintError("The Albers projection cannot be used for phi1==phi2==0. Use Lambert Cylindrical Equal Area instead");
 
 	*x_src = PI;
 	return 0;
@@ -1156,6 +1351,7 @@ int sphere_cp_erect( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int sphere_tp_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam
@@ -1202,6 +1398,7 @@ int sphere_tp_erect( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int erect_sphere_cp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam, double b
@@ -1223,6 +1420,7 @@ int erect_sphere_cp( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int rect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam
@@ -1255,6 +1453,7 @@ int rect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int sphere_tp_rect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {	
 	// params: double distanceparam
@@ -1279,6 +1478,7 @@ int sphere_tp_rect( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int sphere_tp_pano( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam
@@ -1317,6 +1517,7 @@ int sphere_tp_pano( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int pano_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam
@@ -1371,6 +1572,7 @@ int sphere_cp_pano( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int erect_rect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam
@@ -1396,6 +1598,149 @@ int erect_rect( double x_dest,double  y_dest, double* x_src, double* y_src, void
     return 1;
 }
 
+/** convert from erect to biplane */
+int biplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params )
+{
+	double x,offset;
+	if (fabs(x_dest / mp->distance) > mp->pn->precomputedValue[0]+DEG_TO_RAD(89))
+	{
+		*x_src = 0;
+		*y_src = 0;
+		return 0;
+	}
+	if(x_dest<0)
+	{
+		x = x_dest + mp->pn->precomputedValue[0] * mp->distance;
+		offset = -mp->pn->precomputedValue[1];
+	}
+	else
+	{
+		x = x_dest - mp->pn->precomputedValue[0] * mp->distance;
+		offset = mp->pn->precomputedValue[1];
+	}
+	rect_erect(x,y_dest,x_src,y_src,&mp->distance);
+	*x_src += offset;
+	return 1;
+}
+
+/** convert from biplane to erect */
+int erect_biplane		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params )
+{
+	double x, offset;
+	if(fabs(x_dest)>mp->pn->precomputedValue[1]+mp->distance*57)  // 57 = tan(89)
+	{
+		*x_src = 0;
+		*y_src = 0;
+		return 0;
+	}
+	if(x_dest<0)
+	{
+		x=x_dest + mp->pn->precomputedValue[1];
+		offset = - mp->pn->precomputedValue[0];
+	}
+	else
+	{
+		x=x_dest - mp->pn->precomputedValue[1];
+		offset = mp->pn->precomputedValue[0]; 
+	} 
+	erect_rect(x,y_dest,x_src,y_src,&mp->distance);
+	*x_src += offset * mp->distance;
+	return 1;
+}
+
+
+int biplane_distance ( double width, double b, void* params )
+{
+	if(mp->pn->formatParamCount==0)
+	{
+		mp->pn->formatParamCount = 1;
+		mp->pn->formatParam[0] = 45;
+	};
+	mp->pn->formatParam[0]= max( min(mp->pn->formatParam[0], 179), 1);
+
+	mp->pn->precomputedCount = 2;
+	mp->pn->precomputedValue[0] = DEG_TO_RAD(mp->pn->formatParam[0]) / 2;  // angle in rad
+	mp->distance = (double) width / (2.0 * (tan(mp->pn->precomputedValue[0])+tan(b/2.0 - mp->pn->precomputedValue[0])));
+	mp->pn->precomputedValue[1]=mp->distance*tan(mp->pn->precomputedValue[0]);  // offset
+	return 1;
+}
+
+int triplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params )
+{
+	double x,offset;
+	if(fabs(x_dest / mp->distance)> mp->pn->precomputedValue[0] + DEG_TO_RAD(89))
+	{
+		*x_src = 0;
+		*y_src = 0;
+		return 0;
+	};
+	if(x_dest < -mp->pn->precomputedValue[0] / 2)
+	{
+		x=x_dest -mp->pn->precomputedValue[0] * mp->distance;
+		offset = mp->pn->precomputedValue[1];
+	}
+	else if (x_dest < mp->pn->precomputedValue[0] / 2)
+	{
+		x=x_dest;
+		offset=0;
+	}
+	else
+	{
+		x=x_dest + mp->pn->precomputedValue[0] * mp->distance;
+		offset = - mp->pn->precomputedValue[1];
+	}
+	rect_erect(x,y_dest,x_src,y_src,&mp->distance);
+	*x_src += offset;
+	return 1;
+}
+
+int erect_triplane		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params )
+{
+	double x, offset;
+	if(fabs(x_dest) > 2* mp->pn->precomputedValue[1] + 57 * mp->distance )
+	{
+		*x_src = 0;
+		*y_src = 0;
+		return 0;
+	};
+	if(x_dest < -mp->pn->precomputedValue[1])
+	{
+		x=x_dest + 2 * mp->pn->precomputedValue[1];
+		offset = - mp->pn->precomputedValue[0];
+	}
+	else if (x_dest < mp->pn->precomputedValue[1])
+	{
+		x=x_dest;
+		offset=0;
+	}
+	else
+	{
+		x=x_dest - 2 * mp->pn->precomputedValue[1];
+		offset = + mp->pn->precomputedValue[0];
+	}
+	erect_rect(x,y_dest,x_src ,y_src,&mp->distance);
+	*x_src += offset * mp->distance;
+	return 1;
+}
+
+int triplane_distance ( double width, double b, void* params )
+{
+	if(mp->pn->formatParamCount==0)
+	{
+		mp->pn->formatParamCount = 1;
+		mp->pn->formatParam[0] = 45;
+	};
+	mp->pn->formatParam[0] = max( min(mp->pn->formatParam[0], 120), 1);
+
+	mp->pn->precomputedCount = 2;
+	mp->pn->precomputedValue[0] = DEG_TO_RAD(mp->pn->formatParam[0]);  // angle in rad
+	mp->distance = (double) width / (4.0 * tan(mp->pn->precomputedValue[0]/2.0) + 2 * tan(b/2.0 - mp->pn->precomputedValue[0]));
+	mp->pn->precomputedValue[1]=mp->distance*tan(mp->pn->precomputedValue[0]/2.0);  // offset
+	return 1;
+}
+
+
+
 
 int erect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
@@ -1438,6 +1783,7 @@ int erect_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src,
     return 1;
 }
 
+
 int mirror_sphere_cp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam, double b
@@ -1454,6 +1800,7 @@ int mirror_sphere_cp( double x_dest,double  y_dest, double* x_src, double* y_src
     return 1;
 }
 
+
 int mirror_erect( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam, double b, double b2
@@ -1470,6 +1817,7 @@ int mirror_erect( double x_dest,double  y_dest, double* x_src, double* y_src, vo
     return 1;
 }
 
+
 int mirror_pano( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam, double b
@@ -1487,6 +1835,7 @@ int mirror_pano( double x_dest,double  y_dest, double* x_src, double* y_src, voi
     return 1;
 }
 
+
 int sphere_cp_mirror( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
 {
 	// params: double distanceparam, double b
@@ -1503,6 +1852,83 @@ int sphere_cp_mirror( double x_dest,double  y_dest, double* x_src, double* y_src
     return 1;
 }
 
+/*
+int sphere_tp_mirror( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+{
+  return 1;
+}
+
+int mirror_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params);
+{
+  return 1;
+}
+*/
+
+int sphere_tp_equisolid( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+  // params: double distance
+
+  register double phi, theta, rho;
+
+  rho = sqrt( x_dest*x_dest + y_dest*y_dest );
+  
+  theta = 2.0 * asin( rho/(2.0*((double*)params)[0]) );
+  phi   = atan2( y_dest , x_dest );
+
+  *x_src = ((double*)params)[0] * theta * cos( phi );
+  *y_src = ((double*)params)[0] * theta * sin( phi );
+  return 1;
+}
+
+
+int equisolid_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+  // params: double distance
+
+  register double rho, phi, theta;
+
+  theta = sqrt( x_dest * x_dest + y_dest * y_dest ) / ((double*)params)[0];
+  phi   = atan2( y_dest , x_dest );
+  
+  rho = 2.0 * ((double*)params)[0] * sin( theta / 2.0 );
+  
+  *x_src = rho * cos( phi );
+  *y_src = rho * sin( phi );
+  return 1;
+}
+
+int sphere_tp_orthographic( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+  // params: double distance
+
+  register double phi, theta, rho;
+
+  rho = sqrt( x_dest*x_dest + y_dest*y_dest );
+  
+  theta = 1.0 * asin( rho/(1.0*((double*)params)[0]) );
+  phi   = atan2( y_dest , x_dest );
+
+  *x_src = ((double*)params)[0] * theta * cos( phi );
+  *y_src = ((double*)params)[0] * theta * sin( phi );
+  return 1;
+}
+
+
+int orthographic_sphere_tp( double x_dest,double  y_dest, double* x_src, double* y_src, void* params)
+{
+  // params: double distance
+
+  register double rho, phi, theta;
+
+  theta = sqrt( x_dest * x_dest + y_dest * y_dest ) / ((double*)params)[0];
+  phi   = atan2( y_dest , x_dest );
+  
+  rho = 1.0 * ((double*)params)[0] * sin( theta / 1.0 );
+  
+  *x_src = rho * cos( phi );
+  *y_src = rho * sin( phi );
+  return 1;
+}
 
 int shift_scale_rotate( double x_dest,double  y_dest, double* x_src, double* y_src, void* params){
 	// params: double shift_x, shift_y, scale, cos_phi, sin_phi
@@ -1519,14 +1945,6 @@ int shift_scale_rotate( double x_dest,double  y_dest, double* x_src, double* y_s
 
 
 
-
-
-
-
-
-
-
-
 // Correct radial luminance change using parabel
 
 unsigned char radlum( unsigned char srcPixel, int xc, int yc, void *params )
