@@ -50,6 +50,7 @@
 
 /* defined in adjust.c */
 int AddEdgePoints( AlignInfo *gl );
+void setFcnPanoHuberSigma(double sigma);
 
 static int      ReadControlPoint    ( controlPoint * cptr, char *line);
 static int      ReadImageDescription( Image *imPtr, stBuf *sPtr, char *line );
@@ -228,17 +229,20 @@ int ParseScript( char* script, AlignInfo *gl )
                                         READ_VAR( "%d", &k );
                                         switch (k)
                                         {
-                                            case 0:   im->format = _rectilinear;    break;
-                                            case 1:   im->format = _panorama;
+                                          case IMAGE_FORMAT_RECTILINEAR:                im->format = _rectilinear;    break;
+                                          case IMAGE_FORMAT_PANORAMA:                   im->format = _panorama;
                                                         im->cP.correction_mode |= correction_mode_vertical;
                                                         break;
-                                            case 2:   im->format = _fisheye_circ;   break;
-                                            case 3:   im->format = _fisheye_ff;     break;
-                                            case 4:   im->format = _equirectangular;
+                                          case IMAGE_FORMAT_FISHEYE_EQUIDISTANCECIRC:   im->format = _fisheye_circ;   break;
+                                          case IMAGE_FORMAT_FISHEYE_EQUIDISTANCEFF:     im->format = _fisheye_ff;     break;
+                                          case IMAGE_FORMAT_EQUIRECTANGULAR:            im->format = _equirectangular;
                                                         im->cP.correction_mode |= correction_mode_vertical;
                                                         break;
-                                            case 8:   im->format = _orthographic; break;
-                                            default:  PrintError("Syntax error in script: Line %d", lineNum);
+                                          case IMAGE_FORMAT_MIRROR:                     im->format = _mirror; break;
+                                          case IMAGE_FORMAT_FISHEYE_ORTHOGRAPHIC:       im->format = _orthographic; break;
+                                          case IMAGE_FORMAT_FISHEYE_STEREOGRAPHIC:      im->format = _stereographic; break;
+                                          case IMAGE_FORMAT_FISHEYE_EQUISOLID:          im->format = _equisolid; break;
+                                          default:  PrintError("Syntax error in script: Line %d", lineNum);
                                                         return -1;
                                                         break;
                                         }
@@ -491,6 +495,27 @@ int ParseScript( char* script, AlignInfo *gl )
                         case PANO_FORMAT_MILLER_CYLINDRICAL:
                             gl->pano.format = _millercylindrical;
                             break;
+                        case PANO_FORMAT_PANINI:
+                            gl->pano.format = _panini;
+                            break;
+                        case PANO_FORMAT_EQUI_PANINI:
+                            gl->pano.format = _equipanini;
+                            break;
+                        case PANO_FORMAT_ARCHITECTURAL:
+                            gl->pano.format = _architectural;
+                            break;
+                        case PANO_FORMAT_ORTHOGRAPHIC:
+                            gl->pano.format = _orthographic;
+                            break;
+                        case PANO_FORMAT_EQUISOLID:
+                            gl->pano.format = _equisolid;
+                            break;
+						case PANO_FORMAT_BIPLANE:
+							gl->pano.format = _biplane;
+							break;
+						case PANO_FORMAT_TRIPLANE:
+							gl->pano.format = _triplane;
+							break;
                         default:
                             PrintError( "Unknown panorama projection: %d", gl->pano.format );
                             return -1;
@@ -547,7 +572,7 @@ int ParseScript( char* script, AlignInfo *gl )
     
     if( gl->pano.width == 0 && gl->im[0].hfov != 0.0)  // Set default for panorama width based on first image
     {
-        gl->pano.width = ( gl->pano.hfov / gl->im[0].hfov ) * gl->im[0].width;
+        gl->pano.width = (pt_int32)(( gl->pano.hfov / gl->im[0].hfov ) * gl->im[0].width);
         gl->pano.width /= 10; gl->pano.width *= 10; // Round to multiple of 10
     }
 
@@ -611,7 +636,7 @@ int ParseScript( char* script, AlignInfo *gl )
 
 void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int i), int launch)
 {
-    char        *res, **hres, line[LINE_LENGTH], cmd[LINE_LENGTH];
+    char        *res, **hres, *line;
     int         optHfov;         // Has hfov being optimized?
     int         opta,optb,optc;  // same for a,b,c - the polynomial corrections
     int         format;
@@ -625,45 +650,59 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
         PrintError("Not enough memory to create resultfile");
         return;
     }
-    res = *hres;
-    *res = 0;
-    strcat( res, script );
-    sprintf( line, "\n*\n\n" ); strcat( res, line );
-    sprintf( line, "# ====================================================================\n");strcat( res, line );
-    sprintf( line, "# Output  generated by Panorama Tools\n\n" );strcat( res, line );
+    line = res = *hres;
+    line += sprintf( line, "%s", script );
+    line += sprintf( line, "\n*\n\n" );
+    line += sprintf( line, "# ====================================================================\n");
+    line += sprintf( line, "# Output  generated by Panorama Tools\n\n" );
     if( g->data != NULL )
-        strcat( res, (char*) g->data );
-    
-        
-    sprintf( line, "\n# Panorama description\n" );strcat( res, line );
+        line += sprintf( line, "%s", (char*) g->data );
+
+    line += sprintf( line, "\n# Panorama description\n" );
     switch( g->pano.format )
     {
-                case _mercator:             format = 4; break;
-                case _equirectangular:      format = 2; break;
-        case _rectilinear:          format = 0; break;
-        case _panorama:             format = 1; break;
-        default:            format = -1; break;
+        case _rectilinear:            format = PANO_FORMAT_RECTILINEAR; break;
+        case _panorama:               format = PANO_FORMAT_PANORAMA; break;
+        case _equirectangular:        format = PANO_FORMAT_EQUIRECTANGULAR; break;
+        case _fisheye_ff:             format = PANO_FORMAT_FISHEYE_FF; break;
+        case _stereographic:          format = PANO_FORMAT_STEREOGRAPHIC; break;
+        case _mercator:               format = PANO_FORMAT_MERCATOR; break;
+        case _trans_mercator:         format = PANO_FORMAT_TRANS_MERCATOR; break;
+        case _sinusoidal:             format = PANO_FORMAT_SINUSOIDAL; break;
+        case _lambert:                format = PANO_FORMAT_LAMBERT_EQUAL_AREA_CONIC; break;
+        case _lambertazimuthal:       format = PANO_FORMAT_LAMBERT_AZIMUTHAL; break;
+        case _albersequalareaconic:   format = PANO_FORMAT_ALBERS_EQUAL_AREA_CONIC; break;
+        case _millercylindrical:      format = PANO_FORMAT_MILLER_CYLINDRICAL; break;
+        case _panini:                 format = PANO_FORMAT_PANINI; break;
+        case _equipanini:             format = PANO_FORMAT_EQUI_PANINI; break;
+        case _architectural:          format = PANO_FORMAT_ARCHITECTURAL; break;
+        case _orthographic:           format = PANO_FORMAT_ORTHOGRAPHIC; break;
+        case _equisolid:              format = PANO_FORMAT_EQUISOLID; break;
+		case _biplane:                format = PANO_FORMAT_BIPLANE; break;
+		case _triplane:               format = PANO_FORMAT_TRIPLANE; break;
+        default:                      format = -1; break;
     }
-        
-    sprintf( line, "# p f%d w"FMT_INT32" h"FMT_INT32" v%g n\"%s\"\n\n", format, g->pano.width, g->pano.height, g->pano.hfov, g->pano.name );strcat( res, line );
-    
-    
-    
-    sprintf( line, "# Parameters for Each Input Image:\n" );strcat( res, line );
-    sprintf( line, "# (*) - optimized         (p) - preset \n\n");strcat( res, line );
-            
+
+    line += sprintf( line, "# p f%d w"FMT_INT32" h"FMT_INT32" v%g n\"%s\"\n\n", format, g->pano.width, g->pano.height, g->pano.hfov, g->pano.name );
+
+    line += sprintf( line, "# Parameters for Each Input Image:\n" );
+    line += sprintf( line, "# (*) - optimized         (p) - preset \n\n");
+
     for( i=0; i<g->numIm; i++ )
     {
         switch( g->im[i].format )
         {
-            case _rectilinear       : format = 0; break;
-            case _panorama          : format = 1; break;
-            case _fisheye_circ      : format = 2; break;
-            case _fisheye_ff        : format = 3; break;
-            case _equirectangular   : format = 4; break;
-            default: break;
+            case _rectilinear:        format = IMAGE_FORMAT_RECTILINEAR; break;
+            case _panorama:           format = IMAGE_FORMAT_PANORAMA; break;
+            case _fisheye_circ:       format = IMAGE_FORMAT_FISHEYE_EQUIDISTANCECIRC; break;
+            case _fisheye_ff:         format = IMAGE_FORMAT_FISHEYE_EQUIDISTANCEFF; break;
+            case _equirectangular:    format = IMAGE_FORMAT_EQUIRECTANGULAR; break;
+            case _mirror:             format = IMAGE_FORMAT_MIRROR; break;
+            case _orthographic:       format = IMAGE_FORMAT_FISHEYE_ORTHOGRAPHIC; break;
+            case _stereographic:      format = IMAGE_FORMAT_FISHEYE_STEREOGRAPHIC; break;
+            case _equisolid:          format = IMAGE_FORMAT_FISHEYE_EQUISOLID; break;
+            default:                  format = -1; break;
         }
-        sprintf( cmd, "o f%d ", format );
 
         if( g->opt[i].hfov == 1 ||
             ( g->opt[i].hfov > 1 &&  g->opt[g->opt[i].hfov-2].hfov == 1 ))
@@ -689,8 +728,8 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
         else
             optc = 0;
 
-        sprintf( line, "# Image No %d:\n", i );strcat( res, line );
-        sprintf( line, "# Yaw:  %g deg (%c) Pitch:  %g deg (%c) \n# Roll:   %g deg (%c) HFov:   %g deg (%c)\n# Polynomial Coefficients: a   %f (%c); b   %f (%c); c   %f (%c)\n# Horizontal Shift: %f (%c)   Vertical Shift:  %f (%c)\n",
+        line += sprintf( line, "# Image No %d:\n", i );
+        line += sprintf( line, "# Yaw:  %g deg (%c) Pitch:  %g deg (%c) \n# Roll:   %g deg (%c) HFov:   %g deg (%c)\n# Polynomial Coefficients: a   %f (%c); b   %f (%c); c   %f (%c)\n# Horizontal Shift: %f (%c)   Vertical Shift:  %f (%c)\n",
                     g->im[i].yaw, ( g->opt[i].yaw ? '*' : 'p' ),
                     g->im[i].pitch,  ( g->opt[i].pitch  ? '*' : 'p' ),
                     g->im[i].roll, ( g->opt[i].roll ? '*' : 'p' ),
@@ -701,80 +740,74 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
                     g->im[i].cP.horizontal_params[0], (g->opt[i].d ? '*':'p'),
                     g->im[i].cP.vertical_params[0], (g->opt[i].e ? '*':'p')
                     );
-        strcat( res, line );
-        sprintf( line, "r%g p%g y%g v%g ", g->im[i].roll,g->im[i].pitch,g->im[i].yaw,g->im[i].hfov);
-        strcat( cmd, line );
+        if( opta || optb || optc )
+        {
+            line += sprintf(line,"# 4th polynomial coefficient: %g\n", 1.0 - ( g->im[i].cP.radial_params[0][3]
+                                                                 + g->im[i].cP.radial_params[0][2]
+                                                                 + g->im[i].cP.radial_params[0][1] ) );
+        }
+        line += sprintf(line, "# Command for Panorama Creation: \n" );
+        line += sprintf( line, "o f%d r%g p%g y%g v%g ", format, g->im[i].roll,g->im[i].pitch,g->im[i].yaw,g->im[i].hfov);
         if( g->im[i].cP.radial )
         {
-            sprintf( line, "a%f b%f c%f ", g->im[i].cP.radial_params[0][3], g->im[i].cP.radial_params[0][2], g->im[i].cP.radial_params[0][1]);
-            strcat( cmd, line );
+            line += sprintf( line, "a%f b%f c%f ", g->im[i].cP.radial_params[0][3], g->im[i].cP.radial_params[0][2], g->im[i].cP.radial_params[0][1]);
         }
         if( g->im[i].cP.shear )
         {
-            sprintf( line, "g%f t%f ", g->im[i].cP.shear_x, g->im[i].cP.shear_y);
-            strcat( cmd, line );
+            line += sprintf( line, "g%f t%f ", g->im[i].cP.shear_x, g->im[i].cP.shear_y);
         }
         if( g->im[i].cP.cutFrame &&
          !( g->im[i].selection.bottom != 0 || g->im[i].selection.right != 0 )) // g->im[i].format != _fisheye_circ && g->im[i].cP.cutFrame )
         {
             if( g->im[i].cP.frame != 0 )
             {
-                sprintf( line, "m%d ",g->im[i].cP.frame );
+                line += sprintf( line, "m%d ",g->im[i].cP.frame );
             }
             else
             {
-                sprintf( line, "mx%d my%d ",g->im[i].cP.fwidth, g->im[i].cP.fheight );
+                line += sprintf( line, "mx%d my%d ",g->im[i].cP.fwidth, g->im[i].cP.fheight );
             }
-            strcat( cmd, line );
         }
 
-//      sprintf( line, "d%f e%f ", g->prefs[i]->c_prefs.horizontal_params[0], g->prefs[i]->c_prefs.vertical_params[0]);
-//      strcat( cmd, line );
+//      line += sprintf( line, "d%f e%f ", g->prefs[i]->c_prefs.horizontal_params[0], g->prefs[i]->c_prefs.vertical_params[0]);
 #if 0
         if( g->prefs[i]->colCorrect )
         {
-            sprintf( line, "t%f,%f,%f,%f,%f,%f ", g->prefs[i]->ColCoeff[0][0],
+            line += sprintf( line, "t%f,%f,%f,%f,%f,%f ", g->prefs[i]->ColCoeff[0][0],
                                                         g->prefs[i]->ColCoeff[0][1],
                                                         g->prefs[i]->ColCoeff[1][0],
                                                         g->prefs[i]->ColCoeff[1][1],
                                                         g->prefs[i]->ColCoeff[2][0],
                                                         g->prefs[i]->ColCoeff[2][1]);
-            strcat( cmd, line );
         }
 #endif
         if( g->im[i].cP.horizontal )
         {
-            sprintf( line, "d%f ",g->im[i].cP.horizontal_params[0]); 
-            strcat( cmd, line );
+            line += sprintf( line, "d%f ",g->im[i].cP.horizontal_params[0]); 
         }
         if( g->im[i].cP.vertical )
         {
-            sprintf( line, "e%f ",g->im[i].cP.vertical_params[0]);
-            strcat( cmd, line );
+            line += sprintf( line, "e%f ",g->im[i].cP.vertical_params[0]);
         }
         if( g->im[i].cP.correction_mode & correction_mode_morph )
         {
-            strcat( cmd, "o " );
+            line += sprintf( line, "o " );
         }
         if( g->im[i].selection.bottom != 0 || g->im[i].selection.right != 0 ){
             if( g->im[i].cP.cutFrame ){
-                sprintf( line, " C"FMT_INT32","FMT_INT32","FMT_INT32","FMT_INT32" ",g->im[i].selection.left, g->im[i].selection.right,
+                line += sprintf( line, " C"FMT_INT32","FMT_INT32","FMT_INT32","FMT_INT32" ",g->im[i].selection.left, g->im[i].selection.right,
                                g->im[i].selection.top, g->im[i].selection.bottom );
             }else{
-                sprintf( line, " S"FMT_INT32","FMT_INT32","FMT_INT32","FMT_INT32" ",g->im[i].selection.left, g->im[i].selection.right,
+                line += sprintf( line, " S"FMT_INT32","FMT_INT32","FMT_INT32","FMT_INT32" ",g->im[i].selection.left, g->im[i].selection.right,
                                g->im[i].selection.top, g->im[i].selection.bottom );
             }
-            strcat( cmd, line );
         }
 
-
-        sprintf(line, "u%d ", g->st.feather);
-        strcat( cmd, line );
+        line += sprintf(line, "u%d ", g->st.feather);
 #if 0
         // Print filename
         if( g->im[i].name != NULL && strlen( g->im[i].name != 0 ) ){
-            sprintf(line, " n\"%s\" ", g->im[i].name);
-            strcat( cmd, line );
+            line += sprintf(line, " n\"%s\" ", g->im[i].name);
         }
     
 #endif
@@ -783,54 +816,39 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
         // else add stitch commands
         if( !*(g->st.destName) )
         {
-            
             if( i== 0 )
             {
-                sprintf(line, "-%s ", g->st.srcName);
-                strcat( cmd, line );
+                line += sprintf(line, "-%s ", g->st.srcName);
             }
             else if( i == g->numIm-1 )
             {
-                sprintf(line, "+%s ", g->st.srcName);
-                strcat( cmd, line );
+                line += sprintf(line, "+%s ", g->st.srcName);
             }
             else
             {
-                sprintf(line, "+%s -%s ", g->st.srcName, g->st.srcName);
-                strcat( cmd, line );
+                line += sprintf(line, "+%s -%s ", g->st.srcName, g->st.srcName);
             }
             // Print Feather commands
         }
-        
-                
-        
-        if( opta || optb || optc )
-        {
-            sprintf(line,"# 4th polynomial coefficient: %g\n", 1.0 - ( g->im[i].cP.radial_params[0][3]
-                                                                 + g->im[i].cP.radial_params[0][2]
-                                                                 + g->im[i].cP.radial_params[0][1] ) );
-            strcat( res, line );
-        }
-        sprintf(line, "# Command for Panorama Creation: \n%s\n", cmd );
-        strcat( res, line );
-        sprintf(line, "\n");strcat( res, line );
+        line += sprintf(line, "\n\n");
     } // numIm
 
     if( g->numPts > 0 ) // Display Controlpoint distances
     {
-        sprintf(line, "\n");strcat( res, line );
-        sprintf( line, "# ==========================================================================\n");strcat( res, line );
-        sprintf( line, "# Control Points: Distance between desired and fitted Position (in \"Pixels\")\n\n");strcat( res, line );
-            
+        line += sprintf(line, "\n");
+        line += sprintf( line, "# ==========================================================================\n");
+        line += sprintf( line, "# Control Points: Distance between desired and fitted Position (in \"Pixels\")\n\n");
+
         for( i=0; i<g->numPts; i++ )
         {
-            sprintf( line, "# Control Point No %d:  %g\n", i , sqrt ( ds(i)) );strcat( res, line );
+            line += sprintf( line, "# Control Point No %d:  %g\n", i , sqrt ( ds(i)) );
         }
         // Print optimum positions for points in panorama
         for( i=0; i<g->numPts; i++ )
         {
-            double x[2],y[2],xd,yd;
-            
+            double x[2],y[2],xd,yd,d,D[2];
+
+            EvaluateControlPointErrorAndComponents(i,&d,D);
             // write only normal control points, not horizontals, verticals, or lines
             if (g->cpt[i].type == 0)
             {
@@ -841,8 +859,8 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
                 {
                     xd = (x[0]+x[1]) / 2.0;
                     yd = (y[0]+y[1]) / 2.0;
-                    sprintf( line, "C i%d  x%g y%g X%g Y%g\n", g->cpt[i].num[0] , x[0], y[0], xd, yd );strcat( res, line );
-                    sprintf( line, "C i%d  x%g y%g X%g Y%g\n", g->cpt[i].num[1] , x[1], y[1], xd, yd );strcat( res, line );
+                    line += sprintf( line, "C i%d c%d  x%g y%g X%g Y%g  D%g Dx%g Dy%g\n", g->cpt[i].num[0], i, x[0], y[0], xd, yd, d, D[0], D[1] );
+                    line += sprintf( line, "C i%d c%d  x%g y%g X%g Y%g  D%g Dx%g Dy%g\n", g->cpt[i].num[1], i, x[1], y[1], xd, yd, d, D[0], D[1] );
                 }
             }
         }
@@ -949,47 +967,68 @@ int readAdjust( aPrefs *p,  fullPath* sfile, int insert, sPrefs *sP )
 		    free( script );
 		    return -1;
 		}
-	    switch (p->pano.format) {
-	    case 0:
-		p->pano.format = _rectilinear;
-		break;
-	    case 1:
-		p->pano.format = _panorama;
-		break;
-	    case 2:
-		p->pano.format = _equirectangular;
-		break;
-	    case 3:
-		p->pano.format = _fisheye_ff;
-		break;
-	    case 4:
-		p->pano.format = _stereographic;
-		break;
-	    case 5:
-		p->pano.format = _mercator;
-		break;
-	    case 6:
-		p->pano.format = _trans_mercator;
-		break;
-	    case 7:
-		p->pano.format = _sinusoidal;
-		break;
-	    case 8:
-		p->pano.format = _lambert;
-		break;
-	    case 9:
-		p->pano.format = _lambertazimuthal;
-		break;
-	    case 10:
-		p->pano.format = _albersequalareaconic;
-		break;
-	    case 11:
-		p->pano.format = _millercylindrical;
-		break;
-	    default:
-		PrintError( "Unknown panorama projection: %d", p->pano.format );
-		return -1;
-	    }
+      switch (p->pano.format) {
+        case PANO_FORMAT_RECTILINEAR:
+          p->pano.format = _rectilinear;
+          break;
+        case PANO_FORMAT_PANORAMA:
+          p->pano.format = _panorama;
+          break;
+        case PANO_FORMAT_EQUIRECTANGULAR:
+          p->pano.format = _equirectangular;
+          break;
+        case PANO_FORMAT_FISHEYE_FF:
+          p->pano.format = _fisheye_ff;
+          break;
+        case PANO_FORMAT_STEREOGRAPHIC:
+          p->pano.format = _stereographic;
+          break;
+        case PANO_FORMAT_MERCATOR:
+          p->pano.format = _mercator;
+          break;
+        case PANO_FORMAT_TRANS_MERCATOR:
+          p->pano.format = _trans_mercator;
+          break;
+        case PANO_FORMAT_SINUSOIDAL:
+          p->pano.format = _sinusoidal;
+          break;
+        case PANO_FORMAT_LAMBERT_EQUAL_AREA_CONIC:
+          p->pano.format = _lambert;
+          break;
+        case PANO_FORMAT_LAMBERT_AZIMUTHAL:
+          p->pano.format = _lambertazimuthal;
+          break;
+        case PANO_FORMAT_ALBERS_EQUAL_AREA_CONIC:
+          p->pano.format = _albersequalareaconic;
+          break;
+        case PANO_FORMAT_MILLER_CYLINDRICAL:
+          p->pano.format = _millercylindrical;
+          break;
+        case PANO_FORMAT_PANINI:
+          p->pano.format = _panini;
+          break;
+        case PANO_FORMAT_EQUI_PANINI:
+          p->pano.format = _equipanini;
+          break;
+        case PANO_FORMAT_ARCHITECTURAL:
+          p->pano.format = _architectural;
+          break;
+        case PANO_FORMAT_ORTHOGRAPHIC:
+          p->pano.format = _orthographic;
+          break;
+        case PANO_FORMAT_EQUISOLID:
+          p->pano.format = _equisolid;
+          break;
+		case PANO_FORMAT_BIPLANE:
+          p->pano.format = _biplane;
+          break;
+		case PANO_FORMAT_TRIPLANE:
+	      p->pano.format = _triplane;
+          break;
+        default:
+          PrintError( "Unknown panorama projection: %d", p->pano.format );
+          return -1;
+        }
 	    if( (p->pano.format == _rectilinear || p->pano.format == _trans_mercator) && p->pano.hfov >= 180.0 ) {
 		PrintError( "Destination image must have HFOV < 180" );
 		return -1;
@@ -1325,13 +1364,10 @@ static int ReadImageDescription( Image *imPtr, stBuf *sPtr, char *line )
     stBuf sBuf;
     char *ch = line;
     char buf[LINE_LENGTH];
-    char *b;
     int  i;
     int    cropping = 0;
     int tempInt;
-    double tempDbl;
     char typeParm;
-    char temp;
     
     memcpy( &im,    imPtr,   sizeof(Image) );
     memcpy( &sBuf,  sPtr,    sizeof(stBuf ));
@@ -1524,10 +1560,7 @@ static int ReadPanoramaDescription( Image *imPtr, stBuf *sPtr, char *line )
     char *b;
     int  i;
     int    cropping = 0;
-    int tempInt;
     double tempDbl;
-    char typeParm;
-    char temp;
     
     memcpy( &im,    imPtr,   sizeof(Image) );
     memcpy( &sBuf,  sPtr,    sizeof(stBuf ));
@@ -1624,12 +1657,13 @@ static int ReadModeDescription( sPrefs *sP, char *line )
     char *ch = line;
     char buf[LINE_LENGTH];
     double sigma = 0;
-    // FS+
     int n;
-    // FS-
 
     setlocale(LC_ALL, "C");
     memcpy( &theSprefs,     sP,  sizeof(sPrefs) );
+
+    // set some default values
+    setFcnPanoHuberSigma(0);
     
     while( *ch != 0)
     {
@@ -1647,15 +1681,14 @@ static int ReadModeDescription( sPrefs *sP, char *line )
                         if(theSprefs.optCreatePano != 0)
                             theSprefs.optCreatePano = TRUE;
                         break;
-            // FS+ 
-            // IMPORTANT: fastTransformStep is initialized to 0 in filter.c, function SetSizeDefaults()
             case 'f':   READ_VAR( "%d", &n );
-                        if( n == 0 || n == 1 ) {
-                            if( n == 0 ) fastTransformStep = FAST_TRANSFORM_STEP_NORMAL;    
-                            if( n == 1 ) fastTransformStep = FAST_TRANSFORM_STEP_MORPH;
-                        }
+                        if( n == 0 ) 
+                          theSprefs.fastStep = FAST_TRANSFORM_STEP_NORMAL;    
+                        else if( n == 1 ) 
+                          theSprefs.fastStep = FAST_TRANSFORM_STEP_MORPH;
+                        else
+                          theSprefs.fastStep = FAST_TRANSFORM_STEP_NONE;
                         break;
-            // FS-
             case 'm':   READ_VAR( "%lf", &sigma);
                         setFcnPanoHuberSigma(sigma);
                         break;
@@ -1917,14 +1950,15 @@ aPrefs* readAdjustLine( fullPath *theScript ){
     }
 
     // Use modevalues read from script
-    aP->interpolator = sP.interpolator;
-    aP->gamma   = sP.gamma;
+    aP->interpolator  = sP.interpolator;
+    aP->gamma         = sP.gamma;
+    aP->fastStep      = sP.fastStep;
                 
     // Parse script again, now reading triangles if morphing requested
     if( aP->im.cP.correction_mode & correction_mode_morph ){
         char*               script;
         AlignInfo           ainf;
-        int             nIm, nPts; // Number of image being processed
+        int                 nIm, nPts; // Number of image being processed
         Image               im[2];
                     
         script = LoadScript( theScript) ;
@@ -1964,7 +1998,6 @@ aPrefs* readAdjustLine( fullPath *theScript ){
 
 char *panoParserFindOLine(char *script, int index)
 {
-    char ch;
     char *ptr;
     int count = 0;
 
