@@ -23,8 +23,8 @@ void SetAlignInfoDefaults( AlignInfo *a);
 	#define HELPERS ":Helpers:"
 #endif
  
-#ifdef __Win__
-	#undef HELPERS
+#ifdef WIN32
+  #undef HELPERS
 	#define HELPERS "Helpers\\"
 #endif
 
@@ -359,7 +359,7 @@ JNIEXPORT void JNICALL Java_ptutils_CLoadImage
 		gl->numParam = numParam;
 		
 		// Set pano dimensionw
-		gl->pano.width = gl->im[n].width * gl->pano.hfov / gl->im[n].hfov;
+		gl->pano.width = (pt_int32)(gl->im[n].width * gl->pano.hfov / gl->im[n].hfov);
 		gl->pano.width /= 10; gl->pano.width *= 10;
 		
 			
@@ -371,16 +371,16 @@ JNIEXPORT void JNICALL Java_ptutils_CLoadImage
 		else	// Cylinder
 		{
 			if( gl->im[n].format == _rectilinear )
-				gl->pano.height = gl->im[n].height * cos( DEG_TO_RAD(dYaw) / 2.0 );
+				gl->pano.height = (pt_int32)(gl->im[n].height * cos( DEG_TO_RAD(dYaw) / 2.0 ));
 			else
 			{
 				double vfov = gl->im[n].hfov * (double)gl->im[n].height / (double)gl->im[n].width;
 				
 				
 				if( vfov < 180.0 )
-					gl->pano.height = gl->im[n].height * tan( DEG_TO_RAD(vfov) / 2.0 ) * cos( DEG_TO_RAD(dYaw) / 2.0 ) / ( DEG_TO_RAD(vfov) / 2.0);
+					gl->pano.height = (pt_int32)(gl->im[n].height * tan( DEG_TO_RAD(vfov) / 2.0 ) * cos( DEG_TO_RAD(dYaw) / 2.0 ) / ( DEG_TO_RAD(vfov) / 2.0));
 				else
-					gl->pano.height = gl->im[n].height * tan( DEG_TO_RAD(160.0) / 2.0 ) / ( DEG_TO_RAD(160.0) / 2.0);
+					gl->pano.height = (pt_int32)(gl->im[n].height * tan( DEG_TO_RAD(160.0) / 2.0 ) / ( DEG_TO_RAD(160.0) / 2.0));
 					
 				gl->pano.height /= 10; gl->pano.height *= 10; 
 			}
@@ -1155,6 +1155,7 @@ JNIEXPORT void JNICALL Java_ptutils_CAlignPoint
 	w_seek 	= h_seek 	= (int)(sqrt((double) (*env)->GetArrayLength(env, jseek))+0.5);	
 	
 	pc_Tr 	= (TrformStr *) malloc(sizeof(TrformStr));
+  memset(pc_Tr, 0, sizeof(TrformStr));
 	pc_reg 	= &reg;
 	pc_adj	= (aPrefs*) malloc(sizeof(aPrefs));
 	SetAdjustDefaults(pc_adj);
@@ -1216,8 +1217,9 @@ JNIEXPORT void JNICALL Java_ptutils_CAlignPoint
 	
 	pc_Tr->tool					= _adjust;
 	pc_Tr->mode					= _usedata + _destSupplied;
-	pc_Tr->interpolator			= _poly3;
+	pc_Tr->interpolator			= _spline36;
 	pc_Tr->gamma				= 1.0;
+    pc_Tr->fastStep             = FAST_TRANSFORM_STEP_NONE;
 	pc_Tr->data					= (void*) pc_adj;
 
 	opt.numVars 		= 4;
