@@ -46,15 +46,35 @@ TStringFeature stringFeatures[]={
   // If a lens type is unavailable, set its name to ""
   {"LensType0","Normal (rectilinear)"},
   {"LensType1","Cylindrical"},
-  {"LensType2","Circular"},
-  {"LensType3","Full Frame"},
+  {"LensType2","Fisheye Equidistance Circular"},
+  {"LensType3","Fisheye Equidistance Full Frame"},
   {"LensType4","Equirectangular"},
+  {"LensType5",""},//"_spherical_cp"},
+  {"LensType6",""},//"_spherical_tp"},
+  {"LensType7","Mirror"},
+  {"LensType8","Fisheye Orthographic"},
+  {"LensType9",""},//"_cubic"},
+  {"LensType10","Fisheye Stereographic"},  // fisheye stereographic
+  {"LensType11",""},//"_mercator"},
+  {"LensType12",""},//"_trans_mercator"},
+  {"LensType13",""},//"_trans_panorama"},
+  {"LensType14",""},//"_sinusoidal"},
+  {"LensType15",""},//"_lambert"},
+  {"LensType16",""},//"_lambertazimuthal"},
+  {"LensType17",""},//"_albersequalareaconic"},
+  {"LensType18",""},//"_millercylindrical"},
+  {"LensType19","Fisheye Equisolid"},
+
   // Source lens type crop format (C)ircle or (R)ectangle:
   {"LensMask0","R"},
   {"LensMask1","R"},
   {"LensMask2","C"},
   {"LensMask3","R"},
   {"LensMask4","R"},
+  {"LensMask7","C"},
+  {"LensMask8","C"},
+  {"LensMask10","C"},
+  {"LensMask19","C"},
   // Pano lens type names 
   // If a lens type is unavailable, set its name to ""
   {"PanoType0","Normal (rectilinear)"},
@@ -69,7 +89,16 @@ TStringFeature stringFeatures[]={
   {"PanoType9","Lambert Azimuthal Equal Area"},
   {"PanoType10","Albers Conical Equal Area"},
   {"PanoType11","Miller Cylindrical"},
+  {"PanoType12","Panini"},
+  {"PanoType13","Architectural"},
+  {"PanoType14","Orthographic"},
+  {"PanoType15","Equisolid"},
+  {"PanoType16","Equirectangular Panini"},
+  {"PanoType17","Biplane"},
+  {"PanoType18","Triplane"},
+
   // Filter Types
+
   //   fix: Fixed Windowsize
   //   aa: Antialiasing filter with adaptive filter size
   // Filter Names 
@@ -306,6 +335,13 @@ char *panoFormatNames[PANO_FORMAT_COUNT] = {
     "Lambert Equal Area Azimuthal",
     "Albers Equal Area Conic",
     "Miller Cylindrical",
+    "Panini",
+    "Architectural",
+    "Orthographic",
+    "Equisolid",
+    "Equirectangular Panini",
+	"Biplane",
+	"Triplane",
 };
 
 static int panoFormatID[PANO_FORMAT_COUNT] = {
@@ -320,9 +356,17 @@ static int panoFormatID[PANO_FORMAT_COUNT] = {
     _lambert,
     _lambertazimuthal,
     _albersequalareaconic,
-    _millercylindrical
+    _millercylindrical,
+    _panini,
+    _architectural,
+    _orthographic,
+    _equisolid,
+    _equipanini,
+	_biplane,
+	_triplane,
     };
 
+
 int panoProjectionFormatCount(void)
 {
     // REturn the number of Projection formats available in the library
@@ -363,8 +407,19 @@ int panoProjectionFeaturesQuery(int projection, pano_projection_features *featur
 	break;
     case PANO_FORMAT_EQUIRECTANGULAR:
     case PANO_FORMAT_MILLER_CYLINDRICAL:
+    case PANO_FORMAT_ARCHITECTURAL:
 	break;
+    case PANO_FORMAT_PANINI:
+	features->maxVFOV = 179;
+	features->maxHFOV = 359;
+        break;
+    case PANO_FORMAT_EQUI_PANINI:
+	features->maxVFOV = 179;
+	features->maxHFOV = 359;
+        break;
     case PANO_FORMAT_FISHEYE_FF:
+    case PANO_FORMAT_ORTHOGRAPHIC:
+    case PANO_FORMAT_EQUISOLID:
 	features->maxVFOV = 360;
 	features->maxHFOV = 360;
 	break;
@@ -392,6 +447,22 @@ int panoProjectionFeaturesQuery(int projection, pano_projection_features *featur
 	    features->parm[i].maxValue = +90;
 	}
 	break;
+	case PANO_FORMAT_BIPLANE:
+        features->maxVFOV = 179;
+        features->maxHFOV = 359;
+		features->numberOfParameters = 1;
+		features->parm[0].name = "alpha";
+		features->parm[0].minValue=1;
+		features->parm[0].maxValue=179;
+		break;
+	case PANO_FORMAT_TRIPLANE:
+	    features->maxVFOV = 179;
+        features->maxHFOV = 359;
+        features->numberOfParameters = 1;
+		features->parm[0].name = "alpha";
+		features->parm[0].minValue=1;
+		features->parm[0].maxValue=120;
+		break;
     default:
 	assert(0); // A projection is missing!
 	return 0;
