@@ -58,6 +58,7 @@ caused annoying warnings about unknown tags while loading each tiff source image
 // FS-
 
 #include "sys_win.h"
+#include "direct.h"
 
 #define CG_IDD_PROGRESS                 101
 #define CG_IDS_PROGRESS_CAPTION         102
@@ -193,7 +194,7 @@ int ProgressIntern( int command, char* argument ){
 int infoDlgIntern ( int command, char* argument )	// Display info: same argumenmts as progress
 {
 	char 				text[256];
-	static char			mainMessage[256];						
+	static char			mainMessage[256];
 	static HWND hwDlg;
 
 	MSG	msg;
@@ -266,11 +267,56 @@ int infoDlgIntern ( int command, char* argument )	// Display info: same argumenm
 
 	}
 	return TRUE;
-}				
+}
 
+// Applications will use this path and name to store and retrieve preferences
+BOOL GetPrefsFileName( char *prefname )
+{
+  char Modfname[_MAX_PATH], *name, *appData;
+  char OldDir[_MAX_PATH];
 
+  GetModuleFileName( NULL, Modfname, _MAX_PATH );
+  name = strrchr( Modfname, '.' );
+  if( name!= NULL )
+  {
+    *name = '\0';
+  }
+  name = strrchr( Modfname, '\\' );
+  if( name!= NULL )
+  {
+    name++;
+  }
+  else
+  {
+    name = Modfname;
+  }
 
+  appData = getenv ("APPDATA");
+  if (!appData )
+  {
+    appData = "c:";
+  }
 
+  sprintf( prefname, "%s\\PanoTools", appData, name );
+
+  /* Get the current working directory: */
+  if( getcwd( OldDir, _MAX_PATH ) != NULL )
+  {
+    // Test to see if the panotools folder exist
+    if(-1 == chdir(prefname) )
+    {
+      // If not create the folder
+      mkdir(prefname);
+    }
+    // go back from where we came
+    chdir(OldDir);
+  }
+
+  // Add file name to path
+  sprintf( prefname, "%s\\PanoTools\\%s.prf", appData, name );
+
+  return TRUE;
+}
 
 
 int readPrefs( char* pref, int selector )
@@ -285,25 +331,12 @@ int readPrefs( char* pref, int selector )
 		struct size_Prefs			s;
 		panControls					pc;
 	} prf;
-	char prefname[256], *c;
-	long size;
-
-	FILE 	*prfile;
-	int result = 0;
-
-	GetModuleFileName( NULL, prefname, 256 );
-	c = strrchr( prefname, '\\' );
-	if( c!= NULL )
-	{
-		c++;
-		strcpy( c,"pano12.prf" );
-	}
-	else
-	{
-		strcpy( prefname,".\\pano12.prf" );
-	}
-
+	char  prefname[256];
+	long  size;
+	FILE *prfile;
+	int   result = 0;
 
+	GetPrefsFileName( prefname );
 
 	if( (prfile = fopen( prefname, "rb" )) != NULL )
 	{
@@ -372,9 +405,6 @@ int readPrefs( char* pref, int selector )
 }
 
 
-
-
-
 void writePrefs( char* prefs, int selector )
 {
 
@@ -388,22 +418,10 @@ void writePrefs( char* prefs, int selector )
 		panControls					pc;
 	} prf;
 
-	FILE 	*prfile;
-	char prefname[256], *c;
-
-	GetModuleFileName( NULL, prefname, 256 );
-	c = strrchr( prefname, '\\' );
-	if( c!= NULL )
-	{
-		c++;
-		strcpy( c,"pano12.prf" );
-	}
-	else
-	{
-		strcpy( prefname,".\\pano12.prf" );
-	}
-
+	FILE *prfile;
+	char  prefname[256];
 
+	GetPrefsFileName( prefname );
 
 	if( (prfile = fopen( prefname, "rb" )) != NULL )
 	{
@@ -449,6 +467,10 @@ void writePrefs( char* prefs, int selector )
 		fwrite( &prf, sizeof(prf), 1 , prfile);
 		fclose(prfile);
 	}
+  else
+  {
+    PrintError( "Could not save settings to file %s", prefname);
+  }
 }
 
 
@@ -742,7 +764,7 @@ BOOL APIENTRY DLLInit(HANDLE hInstance, DWORD fdwReason, LPVOID lpReserved)
 {
 
 	if (fdwReason == DLL_PROCESS_ATTACH)
-		hDllInstance = hInstance;
+		hDllInstance = (HINSTANCE)hInstance;
 
 	return TRUE;   // Indicate that the DLL was initialized successfully.
 }
@@ -827,21 +849,28 @@ int makePathToHost ( fullPath *path )
 
 void MakeTempName( fullPath *destPath, char *fname )
 {
-	char path[MAX_PATH_LENGTH];
-	char sname[256];
+	char  sname[256];
+	char *temp_dir;
 
-	sprintf( sname, "pano12.%s", fname );
-	
-	path[0] = 0;
-	
-	GetModuleFileName( NULL, path, 256 );
-	GetShortPathName( path, destPath->name, 256 );
+	sprintf( sname, "pano13.%s", fname );
+
+  temp_dir = getenv ("TEMP");
+	if (!temp_dir )
+  {
+    temp_dir = getenv ("TMP");
+	  if (!temp_dir )
+    {
+      temp_dir = "c:\\";
+    }
+  }
+
+  //GetModuleFileName( NULL, path, 256 );
+	GetShortPathName( temp_dir, destPath->name, 256 );
 
 	if( strrchr( destPath->name, '\\' ) != NULL )
 		sprintf( strrchr( destPath->name, '\\' )+1, "%s", sname );
 	else
 		sprintf( destPath->name, "C:\\%s", sname );
-	
 }
 
 void ConvFileName( fullPath *fspec,char *string)
@@ -905,13 +934,15 @@ int 	StringtoFullPath	(fullPath *path, char *filename){
 	}
 }
 
+#if defined _USRDLL
+// Only include the DLLMain with the dll build of pano13
 BOOL WINAPI
 DllMain (HANDLE hDll, DWORD dwReason, LPVOID lpReserved)
 {
     switch (dwReason)
     {
         case DLL_PROCESS_ATTACH:
-	    hDllInstance = hDll;
+	    hDllInstance = (HINSTANCE)hDll;
            // Code to run when the DLL is loaded
 
 			// FS+
@@ -935,4 +966,4 @@ DllMain (HANDLE hDll, DWORD dwReason, LPVOID lpReserved)
     }
     return TRUE;
 }
-
+#endif
